stm32-metapac

Crates

git

Versions

stm32u5g9vj

Flavors

Txefa

Struct Txefa 

#[repr(transparent)]
pub struct Txefa(pub u32);
FDCAN Tx event FIFO acknowledge register

Tuple Fields

0: u32

Implementations



impl Txefa

pub const fn efai(&self) -> u8

Event FIFO acknowledge index. After the Host has read an element or a sequence of elements from the Tx event FIFO, it has to write the index of the last element read from Tx event FIFO to EFAI. This sets the Tx event FIFO get index TXEFS[EFGI] to EFAI + 1 and updates the FIFO 0 fill level TXEFS[EFFL]

pub const fn set_efai(&mut self, val: u8)

Event FIFO acknowledge index. After the Host has read an element or a sequence of elements from the Tx event FIFO, it has to write the index of the last element read from Tx event FIFO to EFAI. This sets the Tx event FIFO get index TXEFS[EFGI] to EFAI + 1 and updates the FIFO 0 fill level TXEFS[EFFL]